@@ -4,7 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#include <../src/jsapi/jsonld.h>
+#include <../src/lib/jsapi/jsonld.h>
 
 #include <QDebug>
 #include <QJSEngine>
